@@ -1,8 +1,9 @@
 import testenv; testenv.configure_for_tests()
 import sys, weakref
-from sqlalchemy import create_engine, exceptions, select
+from sqlalchemy import create_engine, exceptions, select, MetaData, Table, Column, Integer, String
 from testlib import *
-
+import time
+import gc
 
 class MockDisconnect(Exception):
     pass
@@ -93,6 +94,7 @@ class MockReconnectTest(TestBase):
         assert id(db.pool) != pid
 
         # ensure all connections closed (pool was recycled)
+        gc.collect()
         assert len(dbapi.connections) == 0
 
         conn =db.connect()
@@ -112,6 +114,7 @@ class MockReconnectTest(TestBase):
             pass
 
         # assert was invalidated
+        gc.collect()
         assert len(dbapi.connections) == 0
         assert not conn.closed
         assert conn.invalidated
@@ -161,6 +164,7 @@ class MockReconnectTest(TestBase):
         assert conn.invalidated
 
         # ensure all connections closed (pool was recycled)
+        gc.collect()
         assert len(dbapi.connections) == 0
 
         # test reconnects
@@ -212,7 +216,7 @@ class RealReconnectTest(TestBase):
         assert not conn.invalidated
 
         conn.close()
-
+    
     def test_close(self):
         conn = engine.connect()
         self.assertEquals(conn.execute(select([1])).scalar(), 1)
@@ -275,6 +279,56 @@ class RealReconnectTest(TestBase):
         self.assertEquals(conn.execute(select([1])).scalar(), 1)
         assert not conn.invalidated
 
+class RecycleTest(TestBase):
+    def test_basic(self):
+        for threadlocal in (False, True):
+            engine = engines.reconnecting_engine(options={'pool_recycle':1, 'pool_threadlocal':threadlocal})
+        
+            conn = engine.contextual_connect()
+            self.assertEquals(conn.execute(select([1])).scalar(), 1)
+            conn.close()
 
+            engine.test_shutdown()
+            time.sleep(2)
+    
+            conn = engine.contextual_connect()
+            self.assertEquals(conn.execute(select([1])).scalar(), 1)
+            conn.close()
+    
+class InvalidateDuringResultTest(TestBase):
+    def setUp(self):
+        global meta, table, engine
+        engine = engines.reconnecting_engine()
+        meta = MetaData(engine)
+        table = Table('sometable', meta,
+            Column('id', Integer, primary_key=True),
+            Column('name', String(50)))
+        meta.create_all()
+        table.insert().execute(
+            [{'id':i, 'name':'row %d' % i} for i in range(1, 100)]
+        )
+        
+    def tearDown(self):
+        meta.drop_all()
+        engine.dispose()
+    
+    def test_invalidate_on_results(self):
+        conn = engine.connect()
+        
+        result = conn.execute("select * from sometable")
+        for x in xrange(20):
+            result.fetchone()
+        
+        engine.test_shutdown()
+        try:
+            result.fetchone()
+            assert False
+        except exceptions.DBAPIError, e:
+            if not e.connection_invalidated:
+                raise
+
+        assert conn.invalidated
+    test_invalidate_on_results = testing.fails_on('mysql')    (test_invalidate_on_results)
+        
 if __name__ == '__main__':
     testenv.main()
